summaryrefslogtreecommitdiffstats
path: root/kword/KWCanvas.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit04766b207afba7961d4d802313e426f5a2fbef63 (patch)
treec888ea1027c793e2d0386a7e5a1a0cd077b03cb3 /kword/KWCanvas.h
parentb6edfe41c9395f2e20784cbf0e630af6426950a3 (diff)
downloadkoffice-04766b207afba7961d4d802313e426f5a2fbef63.tar.gz
koffice-04766b207afba7961d4d802313e426f5a2fbef63.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kword/KWCanvas.h')
-rw-r--r--kword/KWCanvas.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/kword/KWCanvas.h b/kword/KWCanvas.h
index f7fffbbd..955ea605 100644
--- a/kword/KWCanvas.h
+++ b/kword/KWCanvas.h
@@ -63,7 +63,7 @@ class KWCanvas : public TQScrollView
TQ_OBJECT
public:
- KWCanvas(const TQString& viewMode, TQWidget *tqparent, KWDocument *d, KWGUI *lGui);
+ KWCanvas(const TQString& viewMode, TQWidget *parent, KWDocument *d, KWGUI *lGui);
virtual ~KWCanvas();
KWDocument * kWordDocument() const { return m_doc; }
@@ -405,13 +405,13 @@ class InteractionPolicy {
/**
* This instanciates a new policy object and decides which policy is created based on the params.
* @param tqparent the tqparent canvas for things like redraw commands.
* @param meaning the mouseMeaning of as it is at 'point'
* @param point the place where the mouseDown is registred.
* @param buttonState which button is used to click, like Qt::LeftButton
* @param keyState which keys are held down at the click, like TQt::ControlButton
*/
- static InteractionPolicy* createPolicy(KWCanvas *tqparent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState buttonState, TQt::ButtonState keyState);
+ static InteractionPolicy* createPolicy(KWCanvas *parent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState buttonState, TQt::ButtonState keyState);
void hadDragEvents() { m_gotDragEvents = true; }
bool gotDragEvents() { return m_gotDragEvents; }
@@ -419,11 +419,11 @@ class InteractionPolicy {
protected:
/**
* Constructor.
* @param tqparent the tqparent canvas.
* @param doInit if true this will initialize the m_frames and m_indexFrame variables.
* @param includeInlineFrames if true the m_frames will include inline frames
*/
- InteractionPolicy(KWCanvas *tqparent, bool doInit = true, bool includeInlineFrames = false);
+ InteractionPolicy(KWCanvas *parent, bool doInit = true, bool includeInlineFrames = false);
TQValueList<FrameIndex> m_indexFrame;
KWCanvas *m_parent;
@@ -441,7 +441,7 @@ class InteractionPolicy {
*/
class FrameResizePolicy : public InteractionPolicy {
public:
- FrameResizePolicy(KWCanvas *tqparent, MouseMeaning meaning, KoPoint &point);
+ FrameResizePolicy(KWCanvas *parent, MouseMeaning meaning, KoPoint &point);
void handleMouseMove(TQt::ButtonState keyState, const KoPoint &point);
KCommand *createCommand();
void finishInteraction();
@@ -460,7 +460,7 @@ class FrameResizePolicy : public InteractionPolicy {
*/
class FrameMovePolicy : public InteractionPolicy {
public:
- FrameMovePolicy(KWCanvas *tqparent, KoPoint &point);
+ FrameMovePolicy(KWCanvas *parent, KoPoint &point);
void handleMouseMove(TQt::ButtonState keyState, const KoPoint &point);
KCommand *createCommand();
void finishInteraction();
@@ -476,7 +476,7 @@ class FrameMovePolicy : public InteractionPolicy {
*/
class FrameSelectPolicy : public InteractionPolicy {
public:
- FrameSelectPolicy(KWCanvas *tqparent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState state, TQt::ButtonState keyState);
+ FrameSelectPolicy(KWCanvas *parent, MouseMeaning meaning, KoPoint &point, TQt::ButtonState state, TQt::ButtonState keyState);
void handleMouseMove(TQt::ButtonState keyState, const KoPoint &point);
KCommand *createCommand();
void finishInteraction();
@@ -405,13 +405,13 @@ class InteractionPolicy {
/**
* This instanciates a new policy object and decides which policy is created based on the params.
- * @param tqparent the tqparent canvas for things like redraw commands.
+ * @param parent the parent canvas for things like redraw commands.
* @param meaning the mouseMeaning of as it is at 'point'
* @param point the place where the mouseDown is registred.
@@ -419,11 +419,11 @@ class InteractionPolicy {
/**
* Constructor.
- * @param tqparent the tqparent canvas.
+ * @param parent the parent canvas.
* @param doInit if true this will initialize the m_frames and m_indexFrame variables.
* @param includeInlineFrames if true the m_frames will include inline frames